@@ -23,6 +23,9 @@ model_parameters.marginaleffects <- function(model,
 
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
 
+  # do not print or report these columns
+  out <- out[, !colnames(out) %in% c("predicted_lo", "predicted_hi"), drop = FALSE]
+
   if (inherits(model, "marginalmeans")) {
     attr(out, "coefficient_name") <- "Marginal Means"
   } else if (inherits(model, "comparisons")) {
@@ -65,7 +68,7 @@ model_parameters.slopes <- model_parameters.marginaleffects
 #' @export
 model_parameters.predictions <- function(model,
                                          ci = 0.95,
-                                         exponentiate = TRUE,
+                                         exponentiate = FALSE,
                                          ...) {
   insight::check_if_installed("marginaleffects")
 
