@@ -19,13 +19,6 @@ plot.compare_parameters <- function(x, ...) {
 }
 
 
-#' @export
-plot.parameters_stan <- function(x, ...) {
-  insight::check_if_installed("see")
-  NextMethod()
-}
-
-
 #' @export
 plot.parameters_simulate <- function(x, ...) {
   insight::check_if_installed("see")
@@ -75,8 +68,15 @@ plot.parameters_efa <- function(x, ...) {
 }
 
 
+#' @importFrom graphics plot
 #' @export
 plot.cluster_analysis <- function(x, ...) {
   insight::check_if_installed("see")
-  NextMethod()
+  plot(datawizard::visualisation_recipe(x, ...))
+}
+
+#' @export
+plot.cluster_analysis_summary <- function(x, ...) {
+  insight::check_if_installed("see")
+  plot(datawizard::visualisation_recipe(x, ...))
 }
