@@ -3,11 +3,11 @@ skip_if(getRversion() < "4.2.0")
 
 test_that("print in pipe", {
   data(iris)
-  out <- capture.output(
+  out <- capture.output({
     lm(Sepal.Length ~ Petal.Length + Species, data = iris) |>
       model_parameters() |>
       print(include_reference = TRUE)
-  )
+  })
   expect_identical(
     out[5],
     "Species [setosa]     |        0.00 |      |                |        |       "
